summaryrefslogtreecommitdiff
path: root/configs/ruby/Ruby.py
diff options
context:
space:
mode:
Diffstat (limited to 'configs/ruby/Ruby.py')
-rw-r--r--configs/ruby/Ruby.py5
1 files changed, 4 insertions, 1 deletions
diff --git a/configs/ruby/Ruby.py b/configs/ruby/Ruby.py
index 7003e6266..735adda27 100644
--- a/configs/ruby/Ruby.py
+++ b/configs/ruby/Ruby.py
@@ -55,11 +55,14 @@ def create_system(options, physmem, piobus = None, dma_devices = []):
network = SimpleNetwork(topology = makeCrossbar(all_cntrls))
#
# determine the total memory size of the ruby system
#
total_mem_size = MemorySize('0B')
for dir_cntrl in dir_cntrls:
total_mem_size.value += dir_cntrl.directory.size.value
+ physmem_size = long(physmem.range.second) - long(physmem.range.first) + 1
+ assert(total_mem_size.value == physmem_size)
ruby_profiler = RubyProfiler(num_of_sequencers = len(cpu_sequencers))
@@ -55,11 +55,14 @@ def create_system(options, physmem, piobus = None, dma_devices = []):
network = SimpleNetwork(topology = makeCrossbar(all_cntrls))
#
- # determine the total memory size of the ruby system
+ # determine the total memory size of the ruby system and verify it is equal
+ # to physmem
#
total_mem_size = MemorySize('0B')